Annotations with ``annotation_clip`` no longer affect ``tight_layout``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Previously, `.text.Annotation.get_tightbbox` always returned the full
`.text.Annotation.get_window_extent` of the object, independent of the value
of ``annotation_clip``. `.text.Annotation.get_tightbbox` now correctly takes
this extra clipping box into account, meaning that `~.text.Annotation`\s that
are not drawn because of ``annotation_clip`` will not count towards the axes
bounding box calculations, such as those done by `~.pyplot.tight_layout`.

This is now consistent with the API described in `~.artist.Artist`, which
specifies that ``get_window_extent`` should return the full extents and
``get_tightbbox`` should "account for any clipping".
